@@ -1,24 +1,22 @@
-from marshal import loads, dumps
-from operator import attrgetter, getitem
-from typing import Any, Type, List, Dict, Optional, Union, Sequence, Callable
-
 from dataclasses import is_dataclass, MISSING
+from marshal import dumps, loads
+from operator import attrgetter, getitem
+from typing import Any, Callable, Dict, List, Optional, Sequence, Type, Union
 
-from .common import Serializer, T, K, AbstractFactory
-from .fields import get_dataclass_fields, FieldInfo, get_typeddict_fields
-from .path_utils import init_structure, CleanPath, CleanKey
-from .schema import Schema, RuleForUnknown, Unknown
+from .common import AbstractFactory, K, Serializer, T
+from .fields import FieldInfo, get_dataclass_fields, get_typeddict_fields
+from .path_utils import CleanKey, CleanPath, init_structure
+from .schema import RuleForUnknown, Schema, Unknown
 from .type_detection import (
-    is_collection, is_tuple, hasargs, is_dict, is_optional,
-    is_union, is_any, is_generic_concrete, is_type_var,
-    is_enum,
-    is_typeddict)
+    hasargs, is_any, is_collection, is_dict, is_enum, is_generic_concrete, is_newtype,
+    is_optional, is_tuple, is_type_var, is_typeddict, is_union,
+)
 
 
 def to_path(key: Union[CleanKey, CleanPath]) -> CleanPath:
     if isinstance(key, tuple):
         return key
-    return key,
+    return (key,)
 
 
 def unpack_fields(dest, fields):
@@ -26,7 +24,7 @@ def unpack_fields(dest, fields):
         dest.update(dest.pop(f, {}))
 
 
-def get_complex_serializer(factory: AbstractFactory,
+def get_complex_serializer(factory: AbstractFactory,  # noqa C901,CCR001
                            schema: Schema[T],
                            fields: Sequence[FieldInfo],
                            getter: Callable[[Any, Any], Any],
@@ -52,7 +50,9 @@ def get_complex_serializer(factory: AbstractFactory,
 
         def serialize(data):
             container, field_containers = loads(pickled)
-            for (inner_container, data_name), (field_name, serializer, *_) in zip(field_containers, field_info):
+            for (
+                (inner_container, data_name), (field_name, serializer, *_)
+            ) in zip(field_containers, field_info):
                 inner_container[data_name] = serializer(getter(data, field_name))
             if unpack_unknown:
                 unpack_fields(container, unknown)
@@ -61,7 +61,7 @@ def get_complex_serializer(factory: AbstractFactory,
         if has_default:
             def serialize(data):
                 container = {
-                    field_name: value
+                    data_name: value
                     for field_name, serializer, data_name, default in field_info
                     for value in (serializer(getter(data, field_name)),)
                     if value != default
@@ -83,15 +83,21 @@ def get_complex_serializer(factory: AbstractFactory,
 
 
 def get_collection_serializer(serializer: Serializer[T]) -> Serializer[List[T]]:
-    return lambda data: [serializer(x) for x in data]
+    def collection_serializer(data):
+        return [serializer(x) for x in data]
+
+    return collection_serializer
 
 
 def get_tuple_serializer(serializers) -> Serializer[List]:
-    return lambda data: [serializer(x) for x, serializer in zip(data, serializers)]
+    def tuple_serializer(data):
+        return [serializer(x) for x, serializer in zip(data, serializers)]
+
+    return tuple_serializer
 
 
 def get_collection_any_serializer() -> Serializer[List[Any]]:
-    return lambda data: [x for x in data]
+    return lambda data: list(data)
 
 
 def get_vars_serializer(factory) -> Serializer:
@@ -112,7 +118,9 @@ def stub_serializer(data: T) -> T:
     return data
 
 
-def get_dict_serializer(key_serializer: Serializer[K], serializer: Serializer[T]) -> Serializer[Dict[Any, Any]]:
+def get_dict_serializer(
+    key_serializer: Serializer[K], serializer: Serializer[T]
+) -> Serializer[Dict[Any, Any]]:
     return lambda data: {
         key_serializer(k): serializer(v) for k, v in data.items()
     }
@@ -152,9 +160,12 @@ def create_serializer(factory, schema: Schema, debug_path: bool, class_: Type) -
     return serializer
 
 
-def create_serializer_impl(factory, schema: Schema, debug_path: bool, class_: Type) -> Serializer:
+def create_serializer_impl(factory, schema: Schema, debug_path: bool,
+                           class_: Type) -> Serializer:  # noqa C901,CCR001
     if class_ in (str, bytearray, bytes, int, float, complex, bool):
         return stub_serializer
+    if is_newtype(class_):
+        return create_serializer_impl(factory, schema, debug_path, class_.__supertype__)
     if is_type_var(class_):
         return get_lazy_serializer(factory)
     if is_dataclass(class_) or (is_generic_concrete(class_) and is_dataclass(class_.__origin__)):
@@ -200,7 +211,8 @@ def create_serializer_impl(factory, schema: Schema, debug_path: bool, class_: Ty
     if is_generic_concrete(class_) and is_dict(class_.__origin__):
         key_type_arg = class_.__args__[0] if class_.__args__ else Any
         value_type_arg = class_.__args__[1] if class_.__args__ else Any
-        return get_dict_serializer(factory.serializer(key_type_arg), factory.serializer(value_type_arg))
+        return get_dict_serializer(factory.serializer(key_type_arg),
+                                   factory.serializer(value_type_arg))
     if is_dict(class_):
         return get_dict_serializer(get_lazy_serializer(factory), get_lazy_serializer(factory))
     if is_generic_concrete(class_) and is_collection(class_.__origin__):
