@@ -1,9 +1,8 @@
-import inspect
 from enum import Enum
-
+import inspect
 from typing import (
-    Collection, Tuple, Optional, Any, Dict, Union, Type,
-    TypeVar, Generic, List, )
+    Any, Collection, Dict, Generic, List, Optional, Tuple, Type, TypeVar, Union, get_type_hints,
+)
 
 LITERAL_TYPES: List[Any] = []
 TYPED_DICT_METAS_TMP: List[Any] = []
@@ -26,7 +25,9 @@ try:
     from typing import TypedDict as PyTypedDict  # type: ignore
 
 
-    class RealPyTypedDict(PyTypedDict): pass  # create real class, because PyTypedDict can be helper function
+    class RealPyTypedDict(PyTypedDict):
+        pass  # create real class, because PyTypedDict can be helper function
+
 
     TYPED_DICT_METAS_TMP.append(type(RealPyTypedDict))
 except ImportError:
@@ -34,8 +35,11 @@ except ImportError:
 
 try:
     from typing_extensions import TypedDict as CompatTypedDict  # type: ignore
-
-    TYPED_DICT_METAS_TMP.append(type(CompatTypedDict))
+    # This is a hack. It exists because typing_extensions.TypedDict
+    # is not guaranteed to be a type, it can also be a function (which it is in 3.9)
+    _Foo = CompatTypedDict("_Foo", {})
+    TYPED_DICT_METAS_TMP.append(type(_Foo))
+    del _Foo
 except ImportError:
     pass
 
@@ -43,6 +47,19 @@ TYPED_DICT_METAS = tuple(TYPED_DICT_METAS_TMP)
 del TYPED_DICT_METAS_TMP
 
 
+def get_self_type_hints(cls: Type) -> Dict[str, Type]:
+    """
+    Returns type hints declared in current class without inherited once
+    """
+    # use __dict__ to fix if __annotations__ is inherited
+    annotations = cls.__dict__.get("__annotations__", {})
+    return {
+        field: type_
+        for field, type_ in get_type_hints(cls).items()
+        if field in annotations
+    }
+
+
 def hasargs(type_, *args) -> bool:
     try:
         if not type_.__args__:
@@ -63,13 +80,17 @@ def issubclass_safe(cls, classinfo) -> bool:
         return result
 
 
+def is_newtype(type_) -> bool:
+    return hasattr(type_, "__supertype__") and hasattr(type_, "__name__")
+
+
 def is_tuple(type_) -> bool:
     try:
         # __origin__ exists in 3.7 on user defined generics
         return (
-                issubclass_safe(type_, tuple) or
-                issubclass_safe(type_.__origin__, Tuple) or
-                issubclass_safe(type_, Tuple)
+            issubclass_safe(type_, tuple) or
+            issubclass_safe(type_.__origin__, Tuple) or
+            issubclass_safe(type_, Tuple)
         )
     except AttributeError:
         return False
@@ -116,7 +137,7 @@ def is_generic(type_: Type) -> bool:
 
 
 def is_none(type_: Type) -> bool:
-    return type_ is type(None)
+    return type_ is type(None)  # noqa E721 because of https://github.com/python/mypy/issues/3060
 
 
 def is_enum(cls: Type) -> bool:
@@ -125,10 +146,10 @@ def is_enum(cls: Type) -> bool:
 
 def args_unspecified(cls: Type) -> bool:
     return (
-            not hasattr(cls, '__args__') or
-            not hasattr(cls, '__parameters__') or
-            (not cls.__args__ and cls.__parameters__) or
-            (cls.__args__ == cls.__parameters__)
+        not hasattr(cls, '__args__') or
+        not hasattr(cls, '__parameters__') or
+        (not cls.__args__ and cls.__parameters__) or
+        (cls.__args__ == cls.__parameters__)
     )
 
 
